@@ -52,5 +52,6 @@ class ReachConsumerClient:
     def __init__(self, url, exchange_name):
         self.client = QueueAsyncClient(url, exchange_name)
 
-    async def consume(self, callback, routing_key):
+    async def consume(self, callback, channel_slug):
+        routing_key = channel_slug
         await self.client.consume(callback, routing_key)
